package org.eclipse.jdt.internal.compiler.classfmt;

package .tmp;

import java.util.Map;
import org.eclipse.jdt.internal.compiler.classfmt.ExternalAnnotationProvider;
import org.eclipse.jdt.internal.compiler.env.IBinaryAnnotation;
import org.eclipse.jdt.internal.compiler.env.ITypeAnnotationWalker;
import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;

class DispatchingAnnotationWalker implements ITypeAnnotationWalker {
  private LookupEnvironment environment;
  
  private ExternalAnnotationProvider.TypeParametersAnnotationWalker typeParametersWalker;
  
  public DispatchingAnnotationWalker(LookupEnvironment environment) {
    this.environment = environment;
  }
  
  public ITypeAnnotationWalker toTypeParameter(boolean isClassTypeParameter, int rank) {
    String source = ExternalAnnotationProvider.this.typeParametersAnnotationSource;
    if (source != null) {
      if (this.typeParametersWalker == null)
        this.typeParametersWalker = new ExternalAnnotationProvider.TypeParametersAnnotationWalker(ExternalAnnotationProvider.this, source.toCharArray(), 0, 0, null, this.environment); 
      return this.typeParametersWalker.toTypeParameter(isClassTypeParameter, rank);
    } 
    return this;
  }
  
  public ITypeAnnotationWalker toTypeParameterBounds(boolean isClassTypeParameter, int parameterRank) {
    if (this.typeParametersWalker != null)
      return this.typeParametersWalker.toTypeParameterBounds(isClassTypeParameter, parameterRank); 
    return this;
  }
  
  public ITypeAnnotationWalker toSupertype(short index, char[] superTypeSignature) {
    Map<String, String> sources = ExternalAnnotationProvider.this.supertypeAnnotationSources;
    if (sources != null) {
      String source = sources.get(String.valueOf(superTypeSignature));
      if (source != null)
        return (ITypeAnnotationWalker)new ExternalAnnotationProvider.SuperTypesAnnotationWalker(ExternalAnnotationProvider.this, source.toCharArray(), this.environment); 
    } 
    return this;
  }
  
  public ITypeAnnotationWalker toField() {
    return this;
  }
  
  public ITypeAnnotationWalker toThrows(int rank) {
    return this;
  }
  
  public ITypeAnnotationWalker toTypeArgument(int rank) {
    return this;
  }
  
  public ITypeAnnotationWalker toMethodParameter(short index) {
    return this;
  }
  
  public ITypeAnnotationWalker toTypeBound(short boundIndex) {
    return this;
  }
  
  public ITypeAnnotationWalker toMethodReturn() {
    return this;
  }
  
  public ITypeAnnotationWalker toReceiver() {
    return this;
  }
  
  public ITypeAnnotationWalker toWildcardBound() {
    return this;
  }
  
  public ITypeAnnotationWalker toNextArrayDimension() {
    return this;
  }
  
  public ITypeAnnotationWalker toNextNestedType() {
    return this;
  }
  
  public IBinaryAnnotation[] getAnnotationsAtCursor(int currentTypeId) {
    return NO_ANNOTATIONS;
  }
}
